@@ -23,7 +23,7 @@ setup <- function (data,
                    lv_estimator = "miiv",            
                    lv_miiv_scaling  = "first.indicator", 
                    lv_final_estimator = "miiv",
-                   ms_allow) {
+                   ms_allow = FALSE) {
   
 
     
@@ -285,7 +285,7 @@ setup <- function (data,
   exog_lag <- sub("&lag", "", exogenous[regexpr("&lag", exogenous)>0])
   exogenous <- c(exog_lag,exog_con)
   
-  orig <- colnames(ts_list[[1]])
+  orig <- colnames(ts_list[[1]]) 
   uexo <- unique(exogenous)
   conv <- conv_vars
   lagg <- paste0(setdiff(orig,unique(exog_con, conv)), "lag")
@@ -295,7 +295,8 @@ setup <- function (data,
   catg <- NULL
   stnd <- if(standardize) setdiff(c(endo,exog), c(catg, conv_vars)) else NULL
   #coln <- c(endo,exog) # future column names of data
-  coln <- unique(c(lagg, orig, mult))
+  coln <- unique(c(lagg, endo, exog_con, mult)) 
+  # cont_endog <- c(endo, exog_con)
   
 
   varLabels <- list(
